@@ -1,4 +1,5 @@
 import configparser
+import os
 
 import typer
 
@@ -12,6 +13,7 @@ from neosctl import profile
 from neosctl import registry
 from neosctl import schema
 from neosctl import spark
+from neosctl import storage
 from neosctl.util import get_user_profile
 from neosctl.util import read_config_dotfile
 
@@ -20,6 +22,7 @@ def _generate_common_schema(
     gateway_api_url: str,
     registry_api_url: str,
     iam_api_url: str,
+    storage_api_url: str,
     profile_name: str,
     config: configparser.ConfigParser,
     profile: schema.Profile = None,
@@ -28,6 +31,7 @@ def _generate_common_schema(
         gateway_api_url=gateway_api_url,
         registry_api_url=registry_api_url,
         iam_api_url=iam_api_url,
+        storage_api_url=storage_api_url,
         profile_name=profile_name,
         config=config,
         profile=profile,
@@ -35,6 +39,7 @@ def _generate_common_schema(
     common_schema.gateway_api_url = common_schema.get_gateway_api_url()
     common_schema.registry_api_url = common_schema.get_registry_api_url()
     common_schema.iam_api_url = common_schema.get_iam_api_url()
+    common_schema.storage_api_url = common_schema.get_storage_api_url()
 
     return common_schema
 
@@ -44,7 +49,12 @@ def callback(
     gateway_api_url: str = typer.Option("", "--gateway-api-url", "--gurl", help="Gateway API URL"),
     registry_api_url: str = typer.Option("", "--registry-api-url", "--rurl", help="Registry API URL"),
     iam_api_url: str = typer.Option("", "--iam-api-url", "--iurl", help="IAM API URL"),
-    profile: str = typer.Option(constant.DEFAULT_PROFILE, "--profile", "-p", help="Profile name"),
+    storage_api_url: str = typer.Option("", "--storage-api-url", "--surl", help="Storage API URL"),
+    profile: str = typer.Option(
+        os.getenv("NEOSCTL_PROFILE", constant.DEFAULT_PROFILE),
+        "--profile", "-p",
+        help="Profile name",
+    ),
 ):
     config = read_config_dotfile()
     user_profile = get_user_profile(config, profile, allow_missing=True)
@@ -53,6 +63,7 @@ def callback(
         gateway_api_url=gateway_api_url,
         registry_api_url=registry_api_url,
         iam_api_url=iam_api_url,
+        storage_api_url=storage_api_url,
         profile_name=profile,
         config=config,
         profile=user_profile,
@@ -72,8 +83,9 @@ app = typer.Typer(name="neosctl", callback=callback)
 app.add_typer(profile.app, name="profile", help="Manage profiles.")
 app.add_typer(auth.app, name="auth", callback=common, help="Manage authentication status.")
 app.add_typer(consume.app, name="consume", callback=common, help="Consume published data products.")
+app.add_typer(iam.app, name="iam", callback=common, help="Manage access policies.")
+app.add_typer(storage.app, name="storage", callback=common, help="Interact with Storage (as a service).")
 app.add_typer(metadata.app, name="metadata", callback=common, help="Manage and browse metadata.")
 app.add_typer(product.app, name="product", callback=common, help="Manage data products.")
 app.add_typer(registry.app, name="registry", callback=common, help="Manage cores and search data products.")
 app.add_typer(spark.app, name="spark", callback=common, help="Manage data product spark/secrets.")
-app.add_typer(iam.app, name="iam", callback=common, help="Manage access policies.")
