@@ -1,5 +1,3 @@
-import json
-import pathlib
 import typing
 
 import httpx
@@ -9,7 +7,6 @@ from neosctl import schema
 from neosctl import util
 from neosctl.auth import ensure_login
 from neosctl.util import process_response
-from neosctl.util import send_output
 
 
 app = typer.Typer()
@@ -59,21 +56,8 @@ def create_from_json(
             json=user_policy.dict(),
         )
 
-    fp = pathlib.Path(filepath)
-    if not fp.exists():
-        send_output(
-            msg="Can not find file: {}".format(fp),
-            exit_code=1,
-        )
-
-    with fp.open() as f:
-        try:
-            user_policy_payload = json.load(f)
-        except json.decoder.JSONDecodeError:
-            send_output(
-                msg="Invalid schema file, must be json format.",
-                exit_code=1,
-            )
+    fp = util.get_file_location(filepath)
+    user_policy_payload = util.load_json_file(fp, "schema")
 
     user_policy = schema.UserPolicy(**user_policy_payload)
 
@@ -98,21 +82,8 @@ def update_from_json(
             json=user_policy.dict(),
         )
 
-    fp = pathlib.Path(filepath)
-    if not fp.exists():
-        send_output(
-            msg="Can not find file: {}".format(fp),
-            exit_code=1,
-        )
-
-    with fp.open() as f:
-        try:
-            user_policy_payload = json.load(f)
-        except json.decoder.JSONDecodeError:
-            send_output(
-                msg="Invalid schema file, must be json format.",
-                exit_code=1,
-            )
+    fp = util.get_file_location(filepath)
+    user_policy_payload = util.load_json_file(fp, "schema")
 
     user_policy = schema.UserPolicy(**user_policy_payload)
 
